package com.atguigu.auth.service.impl;

import com.atguigu.auth.mapper.SysMenuMapper;
import com.atguigu.auth.mapper.SysRoleMapper;
import com.atguigu.auth.service.SysMenuService;
import com.atguigu.auth.service.SysRoleMenuService;
import com.atguigu.common.utlis.MenuHelper;
import com.atguigu.constant.MessageConstant;
import com.atguigu.exception.BunnyException;
import com.atguigu.model.system.SysMenu;
import com.atguigu.vo.system.AssginMenuVo;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * <p>
 * 菜单表 服务实现类
 * </p>
 *
 * @author bunny
 * @since 2024-04-23
 */
@Service
public class SysMenuServiceImpl extends ServiceImpl<SysMenuMapper, SysMenu> implements SysMenuService {
    @Autowired
    private SysRoleMenuService sysRoleMenuService;
    @Autowired
    private SysRoleMapper sysRoleMapper;

    /**
     * 获取菜单
     *
     * @return 菜单列表
     */
    @Override
    public List<SysMenu> findNodes() {
        return MenuHelper.buildTree(list());
    }

    /**
     * 删除菜单
     *
     * @param id 菜单id
     */
    @Override
    public void removeMenuById(Long id) {
        // 判断当前菜单是否有下级菜单
        LambdaQueryWrapper<SysMenu> wrapper = new LambdaQueryWrapper<>();
        wrapper.eq(SysMenu::getParentId, id);

        // 查询菜单列表
        List<SysMenu> sysMenuList = list(wrapper);

        // 为空时可以删除
        if (sysMenuList == null) removeById(id);

        // 如果不为空抛出异常
        throw new BunnyException(MessageConstant.DELETE_MENU_ERROR_HAS_MENUS);
    }

    /**
     * 根据角色获取菜单
     *
     * @param roleId 角色id
     * @return 菜单列表
     */
    @Override
    public List<SysMenu> findSysMenuByRoleId(Long roleId) {
        // 查询所有权限列表
        LambdaQueryWrapper<SysMenu> wrapper = new LambdaQueryWrapper<>();
        wrapper.eq(SysMenu::getStatus, 1);
        List<SysMenu> allSysMenuList = list(wrapper);

        // 根据角色id获取角色权限
        List<Long> menuIdList = sysRoleMapper.selectByRoleId4MenuId(roleId);

        allSysMenuList.forEach(permission -> {
            permission.setSelect(menuIdList.contains(permission.getId()));
        });

        return MenuHelper.buildTree(allSysMenuList);
    }

    /**
     * 给角色分配权限
     *
     * @param assginMenuVo 分配条件
     */
    @Override
    public void doAssign(AssginMenuVo assginMenuVo) {

    }
}
